@@ -15,7 +15,7 @@ import warnings
 from numba.core.errors import NumbaWarning
 warnings.filterwarnings("ignore", category=NumbaWarning)
 
-__version__ = "0.8.0"
+__version__ = "0.8.1"
 
 """
 Copyright 2018, Alexander J. Tarashansky, All rights reserved.
@@ -1727,3 +1727,28 @@ class SAM(object):
             self.SamGui = SAMGUI(self)
             return self.SamGui.SamPlot
             
+    def save(self,fn):
+        import dill
+        if len(fn.split('.pkl')) == 1:
+            fn = fn + '.pkl'
+        self.path_to_file = fn
+        d = {}
+        for k in self.__dict__.keys():
+            d[k] = self.__dict__[k]
+        if 'SamGui' in d.keys():
+            del d['SamGui']
+        with open(fn,'wb') as f:
+            dill.dump(d,f)
+            if 'SamGui' in self.__dict__.keys():
+                dill.dump(self.SamGui,f)
+            
+    def load(self,fn):
+        import dill
+        if len(fn.split('.pkl')) == 1:
+            fn = fn + '.pkl'    
+        with open(fn,'rb') as f:
+            self.__dict__ = dill.load(f)
+            try:
+                self.__dict__['SamGui'] = dill.load(f)
+            except:
+                pass;
